@@ -143,7 +143,7 @@ int soundcard_setup_merge_switches(int cardno)
 			continue;
 		soundcard_setup_merge_sw(soundcard->control.switches, rsoundcard->control.switches, soundcard->no, -1, "control");
 		for (rmixer = rsoundcard->mixers; rmixer; rmixer = rmixer->next) {
-			for (mixer = soundcard->mixers; mixer; mixer = rmixer->next) {
+			for (mixer = soundcard->mixers; mixer; mixer = mixer->next) {
 				if (!strncmp(mixer->info.name, rmixer->info.name, sizeof(mixer->info.name)))
 					break;
 			}
@@ -154,7 +154,7 @@ int soundcard_setup_merge_switches(int cardno)
 			soundcard_setup_merge_sw(mixer->switches, rmixer->switches, soundcard->no, mixer->no, "mixer");
 		}
 		for (rpcm = rsoundcard->pcms; rpcm; rpcm = rpcm->next) {
-			for (pcm = rsoundcard->pcms; pcm; pcm = pcm->next) {
+			for (pcm = soundcard->pcms; pcm; pcm = pcm->next) {
 				if (!strncmp(pcm->info.name, rpcm->info.name, sizeof(pcm->info.name)))
 					break;
 			}
@@ -163,7 +163,7 @@ int soundcard_setup_merge_switches(int cardno)
 				continue;
 			}
 			soundcard_setup_merge_sw(pcm->pswitches, rpcm->pswitches, soundcard->no, pcm->no, "PCM playback");
-			soundcard_setup_merge_sw(pcm->rswitches, rpcm->rswitches, soundcard->no, pcm->no, "PCM record");
+			soundcard_setup_merge_sw(pcm->rswitches, rpcm->rswitches, soundcard->no, pcm->no, "PCM capture");
 		}
 		for (rrawmidi = rsoundcard->rawmidis; rrawmidi; rrawmidi = rrawmidi->next) {
 			for (rawmidi = soundcard->rawmidis; rawmidi; rawmidi = rawmidi->next) {
@@ -287,6 +287,7 @@ static int merge_one_element(struct mixer_element *celement, struct mixer_elemen
 		celement->element.data.teffect1.depth = uelement->element.data.teffect1.depth;
 		celement->element.data.teffect1.delay = uelement->element.data.teffect1.delay;
 		celement->element.data.teffect1.feedback = uelement->element.data.teffect1.feedback;
+		celement->element.data.teffect1.depth_rear = uelement->element.data.teffect1.depth_rear;
 		break;
 	case SND_MIXER_ETYPE_PRE_EFFECT1:
 		if (celement->element.data.peffect1.pparameters)
@@ -350,7 +351,7 @@ int soundcard_setup_merge_data(int cardno)
 		if (cardno >= 0 && soundcard->no != cardno)
 			continue;
 		for (rmixer = rsoundcard->mixers; rmixer; rmixer = rmixer->next) {
-			for (mixer = soundcard->mixers; mixer; mixer = rmixer->next) {
+			for (mixer = soundcard->mixers; mixer; mixer = mixer->next) {
 				if (!strncmp(mixer->info.name, rmixer->info.name, sizeof(mixer->info.name)))
 					break;
 			}
@@ -429,8 +430,8 @@ int soundcard_setup_process_switches(int cardno)
 			for (ctlsw = pcm->rswitches; ctlsw; ctlsw = ctlsw->next) {
 				if (ctlsw->change)
 					if (!soundcard_open_ctl(&ctlhandle, soundcard)) {
-						if ((err = snd_ctl_pcm_record_switch_write(ctlhandle, pcm->no, &ctlsw->s)) < 0)
-							error("PCM record switch '%s' write error: %s", ctlsw->s.name, snd_strerror(err));
+						if ((err = snd_ctl_pcm_capture_switch_write(ctlhandle, pcm->no, &ctlsw->s)) < 0)
+							error("PCM capture switch '%s' write error: %s", ctlsw->s.name, snd_strerror(err));
 					}
 			}
 		}
@@ -450,7 +451,7 @@ int soundcard_setup_process_switches(int cardno)
 					}
 			}
 		}
-		if(ctlhandle) {
+		if (ctlhandle) {
 			snd_ctl_close(ctlhandle);
 			ctlhandle = NULL;
 		}
@@ -483,7 +484,7 @@ int soundcard_setup_process_data(int cardno)
 				mixhandle = NULL;
 			}
 		}
-		if(ctlhandle) {
+		if (ctlhandle) {
 			snd_ctl_close(ctlhandle);
 			ctlhandle = NULL;
 		}
